
//Licensed Materials - Property of IBM 
// Copyright IBM Corporation 2006, 2008. All Rights Reserved.

package com.telelogic.rhapsody.core;


 /**
  * The IRPModelElement interface represents an element in a Rational Rhapsody model, and its methods reflect the behavior shared by the various types of model elements. The specific types of elements in a model are derived from this interface.
  */
public interface IRPModelElement {
	/**
	 * method addAssociation
	 * @throws RhapsodyRuntimeException
	 */
	public IRPAssociationClass addAssociation(IRPRelation end1, IRPRelation end2, String name);
	/**
	 * method addDependency
	 * @throws RhapsodyRuntimeException
	 */
	public IRPDependency addDependency(String dependsOnName, String dependsOnType);
	/**
 	 * Adds a dependency upon another model element.
 	 * @param element the model element that this element depends upon
 	 * @return the dependency created
 	 */
	public IRPDependency addDependencyTo(IRPModelElement element);
	/**
	 * method addNewAggr
	 * @throws RhapsodyRuntimeException
	 */
	public IRPModelElement addNewAggr(String metaType, String name);
	/**
	 * method addProperty
	 * @throws RhapsodyRuntimeException
	 */
	public void addProperty(String propertyKey, String propertyType, String propertyValue);
	/**
	 * method addSpecificStereotype
	 * @throws RhapsodyRuntimeException
	 */
	public void addSpecificStereotype(IRPStereotype stereotype);
	/**
	 * method addStereotype
	 * @throws RhapsodyRuntimeException
	 */
	public IRPStereotype addStereotype(String name, String metaType);
	/**
	 * becomeTemplateInstantiationOf
	 * @throws RhapsodyRuntimeException
	 */
	public void becomeTemplateInstantiationOf(IRPModelElement newVal);
	/**
	 * method changeTo
	 * @throws RhapsodyRuntimeException
	 */
	public IRPModelElement changeTo(String metaClass);
	/**
 	 * Clones a model element.
 	 * @param name the name to use for the new element
 	 * @param newOwner the model element that should be the owner of the new element
 	 * @return the new model element that was created
 	 */
	public IRPModelElement clone(String name, IRPModelElement newOwner);
	/**
 	 * Deletes the specified dependency from the model.
 	 * @param dependency the dependency to be deleted
 	 */
	public void deleteDependency(IRPDependency dependency);
	/**
 	 * Deletes the current model element from the model.
 	 */
	public void deleteFromProject();
	/**
 	 * Returns the most recent error message.
 	 * @return the most recent error message
 	 */
	public String errorMessage();
	/**
	 * method findElementsByFullName
	 * @throws RhapsodyRuntimeException
	 */
	public IRPModelElement findElementsByFullName(String name, String metaClass);
	/**
	 * method findNestedElement
	 * @throws RhapsodyRuntimeException
	 */
	public IRPModelElement findNestedElement(String name, String metaClass);
	/**
	 * method findNestedElementRecursive
	 * @throws RhapsodyRuntimeException
	 */
	public IRPModelElement findNestedElementRecursive(String name, String metaClass);
	/**
 	 * Returns a collection of all the element's tags.
 	 * @return a collection of IRPTag objects representing the element's tags
 	 */
	public IRPCollection getAllTags();
	/**
	 * get property annotations
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getAnnotations();
	/**
	 * get property associationClasses
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getAssociationClasses();
	/**
	 * get property BinaryID
	 * @throws RhapsodyRuntimeException
	 */
	public byte[] getBinaryID();
	/**
	 * get property constraints
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getConstraints();
	/**
	 * get property constraintsByHim
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getConstraintsByHim();
	/**
 	 * Returns a collection of all the element's controlled files.
 	 * @return a collection of IRPControlledFile objects representing the element's controlled files
 	 */
	public IRPCollection getControlledFiles();
	/**
	 * get property dependencies
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getDependencies();
	/**
 	 * Returns the description defined for the element.
 	 * @return the description for the element
 	 */
	public String getDescription();
	/**
	 * get property description in HTML format
	 * @throws RhapsodyRuntimeException
	 */
	public String getDescriptionHTML();
	/**
 	 * Returns the description defined for the element in RTF format.
 	 * @return the description for the element in RTF format
 	 */
	public String getDescriptionRTF();
	/**
	 * get property displayName
	 * @throws RhapsodyRuntimeException
	 */
	public String getDisplayName();
	/**
	 * property displayName in RTF format
	 * @throws RhapsodyRuntimeException
	 */
	public String getDisplayNameRTF();
	/**
 	 * Returns the most recent error message.
 	 * @return the most recent error message
 	 */
	public String getErrorMessage();
	/**
	 * method getFullPathName
	 * @throws RhapsodyRuntimeException
	 */
	public String getFullPathName();
	/**
 	 * Retrieves the full path name of the element as a string in the following format: (class) in (package).
 	 * @return the full path name of the element in the format: (class) in (package)
 	 */
	public String getFullPathNameIn();
	/**
	 * get property GUID
	 * @throws RhapsodyRuntimeException
	 */
	public String getGUID();
	/**
 	 * Returns a collection of all the hyperlinks associated with the element.
 	 * @return a collection of IRPHyperLink objects representing the hyperlinks associated with the element
 	 */
	public IRPCollection getHyperLinks();
	/**
	 * Get the full path of the element's icon
	 * @throws RhapsodyRuntimeException
	 */
	public String getIconFileName();
	/**
	 * get property interfaceName
	 * @throws RhapsodyRuntimeException
	 */
	public String getInterfaceName();
	/**
	 * get property isExternal
	 * @throws RhapsodyRuntimeException
	 */
	public int getIsExternal();
	/**
 	 * Indicates whether the model element is based on the metaclass provided as a parameter.
 	 * @param metaClass The name of the metaclass to check for. The strings to use for this parameter should be taken from the file metaclasses.txt in the Doc directory of the Rhapsody installation.
 	 * @return indication of whether the model element is based on the metaclass specified. 1 means that the model element is based on the metaclass specified, 0 means it is not based on that metaclass.
 	 */
	public int getIsOfMetaClass(String metaClass);
	/**
	 * get property isShowDisplayName
	 * @throws RhapsodyRuntimeException
	 */
	public int getIsShowDisplayName();
	/**
 	 * Checks if the element is an element that can't be resolved by Rhapsody.
 	 * @return indication of whether the element is an unresolved element - 0 if the element can be resolved, 1 if the element is unresolved 
 	 */
	public int getIsUnresolved();
	/**
	 * get property localTags
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getLocalTags();
	/**
	 * get property main diagram
	 * @throws RhapsodyRuntimeException
	 */
	public IRPDiagram getMainDiagram();
	/**
 	 * Gets the name of the metaclass on which the model element is based. Note that if the element is based on a New Term stereotype, the string returned here will be the metaclass on which it is based. To get the name of the New Term stereotype, use the method IRPModelElement.getUserDefinedMetaClass.
 	 * @return the name of the metaclasses on which the model element is based. The string returned will be one of the the metaclass names listed in the file metaclasses.txt in the Doc directory of the Rhapsody installation. For example, for an object of type IRPStereotype, the string "Stereotype" will be returned. 
 	 */
	public String getMetaClass();
	/**
 	 * Returns the name of the element.
 	 * @return the name of the element
 	 */
	public String getName();
	/**
 	 * Gets a collection of all the model elements that are directly under the current element. Note that if you call this method on a package, the returned collection will not include functions, global variables, or global objects contained in the package because these are actually contained in a class called TopLevel. To get the functions, global variables, or global objects contained in a package, use the following IRPPackage methods: getGlobalFunctions(), getGlobalVariables(), and getGlobalObjects().
 	 * @return a collection of IRPModelElement objects representing all the model elements that are directly under the current element 
 	 * <pre>
 	 * {@code
 	 * IRPProject prj = app.openProject("l:\\temp\\_sample_code\\Unit_Tricks.rpy");
 	 * IRPPackage vehiclePackage = prj.addPackage("Vehicles");
 	 * vehiclePackage.addClass("Car");
 	 * vehiclePackage.addClass("Jeep");
 	 * vehiclePackage.addClass("Convertible");
 	 * prj.save();
 	 * IRPCollection elementsInVehiclesPackage = vehiclePackage.getNestedElements();
 	 * IRPModelElement elementInCollection;
 	 * System.out.println("The Vehicles package contains:");
 	 * for (int i = 1; i <= elementsInVehiclesPackage.getCount(); i++) {
 	 * 	elementInCollection = (IRPModelElement)elementsInVehiclesPackage.getItem(i);
 	 * 	System.out.println("\t" + elementInCollection.getName());
 	 * }
 	 * }
 	 * </pre>
 	 */
	public IRPCollection getNestedElements();
	/**
	 * method getNestedElements
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getNestedElementsByMetaClass(String metaClass, int recursive);
	/**
	 * method getNestedElementsRecursive
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getNestedElementsRecursive();
	/**
	 * get property of template
	 * @throws RhapsodyRuntimeException
	 */
	public IRPModelElement getOfTemplate();
	/**
	 * Get the full path of the element's overlay icon
	 * @throws RhapsodyRuntimeException
	 */
	public String getOverlayIconFileName();
	/**
	 * method getOverriddenProperties
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getOverriddenProperties(int recursive);
	/**
	 * method getOverriddenPropertiesByPattern
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getOverriddenPropertiesByPattern(String pattern, int localyOverridenOnly, int withDefaultValues);
	/**
	 * get property owner
	 * @throws RhapsodyRuntimeException
	 */
	public IRPModelElement getOwner();
	/**
 	 * Returns the project that the current element belongs to.
 	 * @return the project the current element belongs to
 	 */
	public IRPProject getProject();
	/**
	 * method getPropertyValue
	 * @throws RhapsodyRuntimeException
	 */
	public String getPropertyValue(String propertyKey);
	/**
	 * method getPropertyValueConditional
	 * @throws RhapsodyRuntimeException
	 */
	public String getPropertyValueConditional(String propertyKey, IRPCollection formalKey, IRPCollection actualValues);
	/**
	 * method getPropertyValueConditionalExplicit
	 * @throws RhapsodyRuntimeException
	 */
	public String getPropertyValueConditionalExplicit(String propertyKey, IRPCollection formalKey, IRPCollection actualValues);
	/**
	 * method getPropertyValueExplicit
	 * @throws RhapsodyRuntimeException
	 */
	public String getPropertyValueExplicit(String propertyKey);
	/**
	 * get property references
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getReferences();
	/**
	 * get property requirementTraceabilityHandle
	 * @throws RhapsodyRuntimeException
	 */
	public int getRequirementTraceabilityHandle();
	/**
	 * Get the the save unit the element belongs to
	 * @throws RhapsodyRuntimeException
	 */
	public IRPUnit getSaveUnit();
	/**
	 * get property stereotype
	 * @throws RhapsodyRuntimeException
	 */
	public IRPStereotype getStereotype();
	/**
 	 * Returns a collection of the stereotypes that have been applied to the element.
 	 * @return the stereotypes that have been applied to the element
 	 */
	public IRPCollection getStereotypes();
	/**
	 * method getTag
	 * @throws RhapsodyRuntimeException
	 */
	public IRPTag getTag(String name);
	/**
	 * get property templateParameters
	 * @throws RhapsodyRuntimeException
	 */
	public IRPCollection getTemplateParameters();
	/**
	 * get property template instantiation
	 * @throws RhapsodyRuntimeException
	 */
	public IRPTemplateInstantiation getTi();
	/**
 	 * Gets the name of the New Term on which the model element is based.
 	 * @return the name of the New Term on which the model element is based. The string returned will be the name of the New Term stereotype that you defined. To get the name of the metaclass on which the New Term is based, use the method IRPModelElement.getMetaClass(). 
 	 */
	public String getUserDefinedMetaClass();
	/**
	 * Check if the element has children
	 * @throws RhapsodyRuntimeException
	 */
	public int hasNestedElements();
	/**
	 * highlight element
	 * @throws RhapsodyRuntimeException
	 */
	public void highLightElement();
	/**
	 * method isATemplate
	 * @throws RhapsodyRuntimeException
	 */
	public int isATemplate();
	/**
	 * determine whether description is in RTF format
	 * @throws RhapsodyRuntimeException
	 */
	public int isDescriptionRTF();
	/**
	 * determine whether displayName is in RTF format
	 * @throws RhapsodyRuntimeException
	 */
	public int isDisplayNameRTF();
	/**
	 * Check if the element is modified
	 * @throws RhapsodyRuntimeException
	 */
	public int isModified();
	/**
	 * Locate the model element in the Browser
	 * @throws RhapsodyRuntimeException
	 */
	public int locateInBrowser();
	/**
	 * property openFeaturesDialog
	 * @throws RhapsodyRuntimeException
	 */
	public void openFeaturesDialog(int newDialog);
	/**
	 * method removeProperty
	 * @throws RhapsodyRuntimeException
	 */
	public void removeProperty(String propertyKey);
	/**
 	 * Removes the specified stereotype from the element.
 	 * @param stereotype the stereotype to be removed from the element
 	 */
	public void removeStereotype(IRPStereotype stereotype);
	/**
 	 * Sets the specified string as the description of the element.
 	 * @param description the string to use as the description of the element
 	 */
	public void setDescription(String description);
	/**
	 * method setDescriptionAndHyperlinks
	 * @throws RhapsodyRuntimeException
	 */
	public void setDescriptionAndHyperlinks(String rtfText, IRPCollection targets);
	/**
	 * set property description in HTML format
	 * @throws RhapsodyRuntimeException
	 */
	public void setDescriptionHTML(String descriptionHTML);
	/**
	 * set property description in RTF format
	 * @throws RhapsodyRuntimeException
	 */
	public void setDescriptionRTF(String descriptionRTF);
	/**
	 * set property displayName
	 * @throws RhapsodyRuntimeException
	 */
	public void setDisplayName(String displayName);
	/**
	 * property displayName in RTF format
	 * @throws RhapsodyRuntimeException
	 */
	public void setDisplayNameRTF(String newVal);
	/**
	 * set property GUID
	 * @throws RhapsodyRuntimeException
	 */
	public void setGUID(String gUID);
	/**
	 * set property isShowDisplayName
	 * @throws RhapsodyRuntimeException
	 */
	public void setIsShowDisplayName(int isShowDisplayName);
	/**
	 * set property main diagram
	 * @throws RhapsodyRuntimeException
	 */
	public void setMainDiagram(IRPDiagram mainDiagram);
	/**
 	 * Sets the specified string as the name of the element.
 	 * @param name the string to use as the name of the element
 	 */
	public void setName(String name);
	/**
	 * set property of template
	 * @throws RhapsodyRuntimeException
	 */
	public void setOfTemplate(IRPModelElement ofTemplate);
	/**
	 * set property owner
	 * @throws RhapsodyRuntimeException
	 */
	public void setOwner(IRPModelElement owner);
	/**
	 * method setPropertyValue
	 * @throws RhapsodyRuntimeException
	 */
	public void setPropertyValue(String propertyKey, String propertyValue);
	/**
	 * set property requirementTraceabilityHandle
	 * @throws RhapsodyRuntimeException
	 */
	public void setRequirementTraceabilityHandle(int requirementTraceabilityHandle);
	/**
 	 * Applies the specified stereotype to the element.
 	 * @param stereotype the stereotype to be applied to the element
 	 */
	public void setStereotype(IRPStereotype stereotype);
	/**
	 * method setTagContextValue
	 * @throws RhapsodyRuntimeException
	 */
	public IRPTag setTagContextValue(IRPTag tag, IRPCollection elements, IRPCollection multiplicities);
	/**
	 * method setTagElementValue
	 * @throws RhapsodyRuntimeException
	 */
	public IRPTag setTagElementValue(IRPTag tag, IRPModelElement val);
	/**
	 * method setTagValue
	 * @throws RhapsodyRuntimeException
	 */
	public IRPTag setTagValue(IRPTag tag, String val);
	/**
	 * set property template instantiation
	 * @throws RhapsodyRuntimeException
	 */
	public void setTi(IRPTemplateInstantiation ti);
	/**
	 * synchronizeTemplateInstantiation
	 * @throws RhapsodyRuntimeException
	 */
	public void synchronizeTemplateInstantiation();
}

